# openGA

[![Build Status](https://app.travis-ci.com/neal-nie/openGA.svg?branch=master)](https://app.travis-ci.com/neal-nie/openGA) [![Codacy Badge](https://api.codacy.com/project/badge/Grade/704a0911fb254509b28fae6d9c750533)](https://app.codacy.com/gh/neal-nie/openGA?utm_source=github.com&utm_medium=referral&utm_content=neal-nie/openGA&utm_campaign=Badge_Grade_Settings) [![Coverage Status](https://coveralls.io/repos/github/neal-nie/openGA/badge.svg?branch=master)](https://coveralls.io/github/neal-nie/openGA?branch=master)
[![PyPI version](https://badge.fury.io/py/openGA.svg)](https://badge.fury.io/py/openGA)

---

## overview

open source genetic algorithm framework.

## todo

### algorithm

- [ ] NSGA

### CI

- [x] codacy
- [ ] read the docs
- [x] pypi
